## Features

- Written in Python with extensive support libraries
- Versatile support for key management solutions
- Exposes the Glitter API through LCDClient

<br/>

# Table of Contents


<br/>

# API Reference


<br/>

# Getting Started


## Requirements

Terra SDK requires <a href="https://www.python.org/downloads/">Python v3.7+</a>.

## Installation

<sub>**NOTE:** _All code starting with a `$` is meant to run on your terminal (a bash prompt). All code starting with a `>>>` is meant to run in a python interpreter, like <a href="https://pypi.org/project/ipython/">ipython</a>._</sub>

Terra SDK can be installed (preferably in a `virtual environment` from PyPI using `pip`) as follows:

```
$ pip install -U glitter_sdk
```

<sub>_You might have `pip3` installed instead of `pip`; proceed according to your own setup._<sub>

❗ If you want to communicate with Terra Classic, use terra-sdk==2.x

## Dependencies

Terra SDK uses <a href="https://python-poetry.org/">Poetry</a> to manage dependencies. To get set up with all the required dependencies, run:

```
$ pip install poetry
$ poetry install
```

## Tests


## Code Quality



<br/>

# Usage Examples


## Getting Blockchain Information


### Async Usage


## Building and Signing Transactions


### Example Using a DB (_recommended_)

# Contributing

Community contribution, whether it's a new feature, correction, bug report, additional documentation, or any other feedback is always welcome. Please read through this section to ensure that your contribution is in the most suitable format for us to effectively process.

<br/>

## Reporting an Issue


## Requesting a Feature



## Contributing Code


### For new contributors, here is a quick guide:


## Documentation Contributions


### Need more information on how to contribute?


# License

This software is licensed under the MIT license. See [LICENSE](./LICENSE) for full disclosure.


